Recoverable

Trait Recoverable 

pub trait Recoverable {
    // Required method
    fn recoverable(&self) -> bool;
}
Indicates if an error allows a parent parser to recover and try something else.

Errors usually are irrecoverable if the input is well-formed, but other constraints failed.

Required Methods

fn recoverable(&self) -> bool

Returns true if the parse failure is recoverable, false otherwise.

Implementors